package com.wimy.gameengine;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.util.AttributeSet;
import android.view.SurfaceHolder;
import android.view.SurfaceView;

public class GameView extends SurfaceView implements SurfaceHolder.Callback {

	GameThread mThread = null;
	SurfaceHolder mHolder = null;
	Context mContext = null;
	
	public GameView(Context context, AttributeSet attrs) {
		super(context, attrs);
		
		mHolder = getHolder();
		mHolder.addCallback(this);
		
		mContext = context;
		
		// Create only. Start is called in surfaceCreated()
		mThread = new GameThread();
	}

	public void surfaceChanged(SurfaceHolder holder, int format, int width,
			int height) {
		WGE.d("surfaceChanged()");
	}

	public void surfaceCreated(SurfaceHolder holder) {

		WGE.d("surfaceCreated()");
		
		mThread.setRunning(true);
        mThread.start();
	}

	public void surfaceDestroyed(SurfaceHolder holder) {
		WGE.d("surfaceDestroyed()");
		
        // we have to tell thread to shut down & wait for it to finish, or else
        // it might touch the Surface after we return and explode
        boolean retry = true;
        
        mThread.setRunning(false);
        while (retry) {
            try {
            	mThread.join();
                retry = false;
            } catch (InterruptedException e) {
            }
        }
	}

	public class GameThread extends Thread {

		private boolean mRun = false;
		private Bitmap mIcon = null;
		
		public GameThread()
		{
			mIcon = BitmapFactory.decodeResource(mContext.getResources(), R.drawable.ic_launcher);
		}
		
        public void setRunning(boolean b) {
            mRun = b;
        }
        
		@Override
		public void run() {
			
			WGE.d("GameThread run() called. Thread ID : " + this.getId());
			Canvas canvas = null;
			
			while ( mRun ) {
				canvas = mHolder.lockCanvas();
				
				if ( canvas != null )
				{
					try {
						synchronized (mHolder) {
							canvas.drawBitmap(mIcon, 0, 0, null);						
						}
					} finally {
						mHolder.unlockCanvasAndPost(canvas);
					}
				}
				
				try {
					WGE.d("Before sleep Thread ID : " + this.getId());
					Thread.sleep(100);
				} catch (InterruptedException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		}
		
	}
}
